==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN włączony</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN wyłączony</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock włączony</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock wyłączony</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Klawiatura numeryczna włączona</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Klawiatura numeryczna wyłączona</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Panel dotykowy włączony</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Panel dotykowy wyłączony</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Przełączanie panela dotykowego</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Przełącznik Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Tryb samolotowy włączony</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Tryb samolotowy wyłączony</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Wyciszenie włączone</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Wyciszenie wyłączone</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Zasilanie zrównoważone</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Oszczędność energii</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Włączono efekty okna</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Wyłączono efekty okna</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Nie udało się włączyć niektórych efektów okna</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN włączony</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN wyłączony</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock włączony</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock wyłączony</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Klawiatura numeryczna włączona</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Klawiatura numeryczna wyłączona</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Panel dotykowy włączony</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Panel dotykowy wyłączony</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Przełączanie panela dotykowego</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Przełącznik Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Tryb samolotowy włączony</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Tryb samolotowy wyłączony</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Wyciszenie włączone</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Wyciszenie wyłączone</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Zasilanie zrównoważone</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Oszczędność energii</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Włączono efekty okna</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Wyłączono efekty okna</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Nie udało się włączyć niektórych efektów okna</translation>
    </message>
</context>
</TS>
